==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/history/translations/history_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>Fecha selecionada</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="59"/>
        <source>History</source>
        <translation>Historial</translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>Módulo de Historia de Escucha</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>Acerca del Módulo de Historia de Escucha</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>Módulo de Historia de Escucha de Qmmp</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>Este módulo colecta información acerca de las pistas escuchadas</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>Configuración del Módulo de Historia de Escucha</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>Formato del título: </translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>Rango de Tiempo</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>De:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>Hasta:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>Semana pasada</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>Mes pasado</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>Ejecutar</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>Canción</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>Distribución</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>Día</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>Conteo de reproducciones</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>Canciones más escuchadas</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>Intérpretes más escuchados</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>Intérprete</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>Géneros más escuchados</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="124"/>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="125"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="200"/>
        <source>MM-yyyy</source>
        <translation>MM-aaaa</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="201"/>
        <source>dd MMMM</source>
        <translation>dd MMMM</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/history/translations/history_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>Fecha selecionada</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="57"/>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="58"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>Módulo de Historia de Escucha</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>Acerca del Módulo de Historia de Escucha</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>Módulo de Historia de Escucha de Qmmp</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>Este módulo colecta información acerca de las pistas escuchadas</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>Configuración del Módulo de Historia de Escucha</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>Formato del título: </translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>Rango de Tiempo</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>De:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>Hasta:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>Semana pasada</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>Mes pasado</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>Ejecutar</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>Canción</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>Distribución</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>Día</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>Conteo de reproducciones</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>Canciones más escuchadas</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>Intérpretes más escuchados</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>Intérprete</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>Géneros más escuchados</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="128"/>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="129"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="196"/>
        <source>MM-yyyy</source>
        <translation>MM-aaaa</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="197"/>
        <source>dd MMMM</source>
        <translation>dd MMMM</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="498"/>
        <source>Add to Playlist</source>
        <translation>Añadir a la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="499"/>
        <source>&amp;View Track Details</source>
        <translation>&amp;Ver detalles de la pista</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="501"/>
        <source>Remove from History</source>
        <translation>Eliminar del historial.</translation>
    </message>
</context>
</TS>
